﻿//	Custom Particle Material Editor
//	Allows use of multi-channel particles in particle systems.
//
//	Code by Doug Clayton
//	Feel free to use or edit.

using UnityEngine;
using UnityEditor;
using System.Collections.Generic;
using System.Linq;

public class MultiChannelParticlesMaterialEditor : MaterialEditor
{	
	public override void OnInspectorGUI() 
	{
		base.OnInspectorGUI();
		
		if(!isVisible)
		{
			return;
		}
		
		Material particleMat = target as Material;
		string[] shaderKeys = particleMat.shaderKeywords;
		
		bool useRedChannel = shaderKeys.Contains("USE_RED");
		bool useGreenChannel = shaderKeys.Contains("USE_GREEN");
		bool useBlueChannel = shaderKeys.Contains("USE_BLUE");
		bool useAlphaChannel = shaderKeys.Contains("USE_ALPHA");
		
		EditorGUI.BeginChangeCheck();
		
		useRedChannel = EditorGUILayout.Toggle("Use Red Channel", useRedChannel);
		useGreenChannel = EditorGUILayout.Toggle("Use Green Channel", useGreenChannel);
		useBlueChannel = EditorGUILayout.Toggle("Use Blue Channel", useBlueChannel);
		useAlphaChannel = EditorGUILayout.Toggle("Use Alpha Channel", useAlphaChannel);
		
		if(EditorGUI.EndChangeCheck())
		{
			var keywords = new List<string> { useRedChannel ? "USE_RED" : "DEFAULT", useGreenChannel ? "USE_GREEN" : "DEFAULT", useBlueChannel ? "USE_BLUE" : "DEFAULT", useAlphaChannel ? "USE_ALPHA" : "DEFAULT" };
			particleMat.shaderKeywords = keywords.ToArray();
			EditorUtility.SetDirty(particleMat);
		}
	}	
}
